@@ -1,4 +1,5 @@
 use crate::message::Message;
+use crate::utils::{id_deserializer, option_id_deserializer};
 use serde::{Deserialize, Serialize};
 
 /// WebSocket 接受数据枚举 Event || ApiResp
@@ -28,6 +29,17 @@ pub enum Event {
     /// 元事件
     #[serde(rename = "meta_event")]
     Meta(MetaEvent),
+
+    /// Nonebot 内部事件
+    #[serde(skip)]
+    Nonebot(NbEvent),
+}
+
+/// Nonebot Event
+#[derive(Debug, Clone)]
+pub enum NbEvent {
+    BotConnect { bot: crate::Bot },
+    BotDisconnect { bot: crate::Bot },
 }
 
 /// 消息事件
@@ -102,13 +114,15 @@ pub struct PrivateMessageEvent {
     /// Event 时间戳
     pub time: i64,
     /// 收到事件的机器人 QQ 号
-    pub self_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub self_id: String,
     /// 消息子类型
     pub sub_type: String,
     /// 消息 ID
     pub message_id: i32,
     /// 发送者 ID
-    pub user_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub user_id: String,
     /// Array 消息内容
     pub message: Vec<Message>,
     /// 原生消息内容
@@ -123,7 +137,8 @@ pub struct PrivateMessageEvent {
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub struct PrivateSender {
     /// 发送者 QQ 号
-    pub user_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub user_id: String,
     /// 昵称
     pub nickname: String,
     /// 性别 male|female|unkown
@@ -138,15 +153,18 @@ pub struct GroupMessageEvent {
     /// Event 时间戳
     pub time: i64,
     /// 收到事件的机器人 QQ 号
-    pub self_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub self_id: String,
     /// 消息子类型
     pub sub_type: String,
     /// 消息 ID
     pub message_id: i32,
     /// 群消息群号
-    pub group_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub group_id: String,
     /// 发送者 ID
-    pub user_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub user_id: String,
     /// 匿名消息 非匿名消息为空
     pub anonymous: Option<Anoymous>,
     /// Array 消息内容
@@ -163,7 +181,8 @@ pub struct GroupMessageEvent {
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub struct GroupSender {
     /// 发送者 QQ 号
-    pub user_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub user_id: String,
     /// 昵称
     pub nickname: String,
     /// 群名片|备注
@@ -186,7 +205,8 @@ pub struct GroupSender {
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub struct Anoymous {
     /// 匿名用户 ID
-    pub id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub id: String,
     /// 匿名用户名称
     pub name: String,
     /// 匿名用户 flag
@@ -199,17 +219,23 @@ pub struct NoticeEvent {
     /// Event 时间戳
     pub time: i64,
     /// 收到事件的机器人 QQ 号
-    pub self_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub self_id: String,
     /// 上报类型
     pub notice_type: String,
     /// 事件子类型
     pub sub_type: Option<String>,
     /// 群消息群号
-    pub group_id: Option<i64>,
+    #[serde(deserialize_with = "option_id_deserializer")]
+    #[serde(default)]
+    pub group_id: Option<String>,
     /// 操作者 QQ 号
-    pub operator_id: Option<i64>,
+    #[serde(deserialize_with = "option_id_deserializer")]
+    #[serde(default)]
+    pub operator_id: Option<String>,
     /// 发送者 ID
-    pub user_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub user_id: String,
     /// 文件信息
     pub file: Option<File>,
     /// 禁言时长，单位秒
@@ -217,7 +243,9 @@ pub struct NoticeEvent {
     /// 被撤回的消息 ID
     pub message_id: Option<i64>,
     /// 目标 QQ 号
-    pub target_id: Option<i64>,
+    #[serde(deserialize_with = "option_id_deserializer")]
+    #[serde(default)]
+    pub target_id: Option<String>,
     /// 群荣耀类型
     pub honor_type: Option<String>,
 }
@@ -241,11 +269,13 @@ pub struct RequestEvent {
     /// Event 时间戳
     pub time: i64,
     /// 收到事件的机器人 QQ 号
-    pub self_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub self_id: String,
     /// 请求类型
     pub request_type: String,
     /// 发送请求的 QQ 号
-    pub user_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub user_id: String,
     /// 验证信息
     pub comment: String,
     /// 请求 flag
@@ -253,7 +283,9 @@ pub struct RequestEvent {
     /// 请求子类型
     pub sub_type: Option<String>,
     /// 群号
-    pub group_id: Option<i64>,
+    #[serde(deserialize_with = "option_id_deserializer")]
+    #[serde(default)]
+    pub group_id: Option<String>,
 }
 
 /// 元事件
@@ -262,7 +294,8 @@ pub struct MetaEvent {
     /// Event 时间戳
     pub time: i64,
     /// 收到事件的机器人 QQ 号
-    pub self_id: i64,
+    #[serde(deserialize_with = "id_deserializer")]
+    pub self_id: String,
     /// 元事件类型 lifecycle|heartbeat
     pub meta_event_type: String,
     /// 事件子类型
@@ -273,6 +306,12 @@ pub struct MetaEvent {
     pub interval: Option<i64>,
 }
 
+#[test]
+fn de_test() {
+    let test_str = "{\"group_id\":101,\"message_id\":111,\"notice_type\":\"group_recall\",\"operator_id\":11,\"post_type\":\"notice\",\"self_id\":11,\"time\":1631193409,\"user_id\":11}\n";
+    let _meta: Event = serde_json::from_str(test_str).unwrap();
+}
+
 /// 元事件状态字段
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub struct Status {
@@ -298,13 +337,13 @@ impl UserId for MessageEvent {
 
 impl UserId for NoticeEvent {
     fn get_user_id(&self) -> String {
-        self.user_id.to_string()
+        self.user_id.clone()
     }
 }
 
 impl UserId for RequestEvent {
     fn get_user_id(&self) -> String {
-        self.user_id.to_string()
+        self.user_id.clone()
     }
 }
 
@@ -316,27 +355,27 @@ pub trait SelfId {
 impl SelfId for MessageEvent {
     fn get_self_id(&self) -> String {
         match self {
-            MessageEvent::Private(p) => p.self_id.to_string(),
-            MessageEvent::Group(g) => g.self_id.to_string(),
+            MessageEvent::Private(p) => p.self_id.clone(),
+            MessageEvent::Group(g) => g.self_id.clone(),
         }
     }
 }
 
 impl SelfId for RequestEvent {
     fn get_self_id(&self) -> String {
-        self.self_id.to_string()
+        self.self_id.clone()
     }
 }
 
 impl SelfId for NoticeEvent {
     fn get_self_id(&self) -> String {
-        self.self_id.to_string()
+        self.self_id.clone()
     }
 }
 
 impl SelfId for MetaEvent {
     fn get_self_id(&self) -> String {
-        self.self_id.to_string()
+        self.self_id.clone()
     }
 }
 
@@ -347,6 +386,10 @@ impl SelfId for Event {
             Event::Request(e) => e.get_self_id(),
             Event::Notice(e) => e.get_self_id(),
             Event::Meta(e) => e.get_self_id(),
+            Event::Nonebot(e) => match e {
+                NbEvent::BotConnect { bot } => bot.bot_id.clone(),
+                NbEvent::BotDisconnect { bot } => bot.bot_id.clone(),
+            },
         }
     }
 }
