@@ -3,14 +3,18 @@ use crate::event::{MessageEvent, SelfId};
 use crate::utils::timestamp;
 use crate::Action;
 use async_trait::async_trait;
+use std::collections::HashMap;
 use std::sync::Arc;
+use tokio::sync::RwLock;
 
+mod action;
 #[doc(hidden)]
 pub mod api;
 #[doc(hidden)]
 pub mod matchers;
 #[doc(hidden)]
 pub mod message_event_matcher;
+/// Preludo for Matcher
 pub mod prelude;
 #[doc(hidden)]
 pub mod set_get;
@@ -19,9 +23,8 @@ pub mod set_get;
 pub type Rule<E> = Arc<dyn Fn(&E, &BotConfig) -> bool + Send + Sync>;
 /// permatcher 函数类型
 pub type PreMatcher<E> = fn(&mut E, BotConfig) -> bool;
-// pub type AfterMatcher<E> = fn(&mut E, BotConfig) -> AfterMatcherResult;
 
-/// 参与匹配的最小单元
+/// 单个匹配器，参与匹配的最小单元
 ///
 /// Matcher 匹配器，每个匹配器对应一个 handle 函数
 #[derive(Clone)]
@@ -33,20 +36,22 @@ where
     pub name: String,
     /// Bot
     pub bot: Option<crate::bot::Bot>,
+    /// Matchers Action Sender
+    action_sender: Option<matchers::ActionSender>,
     /// Matcher 的匹配优先级
-    priority: i8,
+    pub priority: i8,
     /// 前处理函数组，获取 &mut event
     pre_matchers: Vec<Arc<PreMatcher<E>>>,
     /// rule 组
     rules: Vec<Rule<E>>,
     /// 是否阻止事件向下一级传递
-    block: bool,
+    pub block: bool,
     /// Matcher 接口函数与可配置项结构体
-    handler: Arc<dyn Handler<E> + Sync + Send>,
+    handler: Arc<RwLock<dyn Handler<E> + Sync + Send>>,
     /// 是否被禁用
-    disable: bool,
+    pub disable: bool,
     /// 是否为临时 Matcher
-    temp: bool,
+    pub temp: bool,
     /// 过期时间戳
     pub timeout: Option<i64>,
 
@@ -80,12 +85,17 @@ where
 {
     /// 新 Bot 连接时，调用该函数
     fn on_bot_connect(&self, _: Matcher<E>) {}
+    /// Bot 断开连接时，调用该函数
+    fn on_bot_disconnect(&self, _: Matcher<E>) {}
     /// timeout drop 函数
     fn timeout_drop(&self, _: &Matcher<E>) {}
     /// 匹配函数
     fn match_(&self, event: &mut E) -> bool;
     /// 处理函数
     async fn handle(&self, event: E, matcher: Matcher<E>);
+    /// Load config
+    #[allow(unused_variables)]
+    fn load_config(&mut self, config: HashMap<String, toml::Value>) {}
 }
 
 impl<E> Matcher<E>
@@ -98,12 +108,12 @@ where
     /// ``` rust
     /// Matcher {
     ///     name: name,
-    ///     sender: None,
+    ///     bot: None,
     ///     priority: 1,
     ///     pre_matchers: vec![],
     ///     rules: vec![],
     ///     block: true,
-    ///     handler: Arc::new(handler),
+    ///     handler: Arc::new(RwLock::new(handler)),
     ///     disable: false,
     ///     temp: false,
     ///     timeout: None,
@@ -118,11 +128,12 @@ where
         Matcher {
             name: name.to_string(),
             bot: None,
+            action_sender: None,
             priority: 1,
             pre_matchers: vec![],
             rules: vec![],
             block: true,
-            handler: Arc::new(handler),
+            handler: Arc::new(RwLock::new(handler)),
             disable: false,
             temp: false,
             timeout: None,
@@ -155,7 +166,12 @@ where
     }
 
     #[doc(hidden)]
-    pub async fn match_(&self, event: E, config: BotConfig) -> bool
+    pub async fn match_(
+        &self,
+        event: E,
+        config: BotConfig,
+        matchers: &mut matchers::Matchers,
+    ) -> bool
     where
         E: Send + 'static + SelfId,
     {
@@ -163,11 +179,11 @@ where
         let mut event = event.clone();
         if let Some(timeout) = self.timeout {
             if timestamp() > timeout {
-                self.set(Action::RemoveMatcher {
-                    name: self.name.clone(),
-                })
-                .await;
-                self.handler.timeout_drop(&self);
+                matchers.remove_matcher(&self.name);
+                {
+                    let handler = self.handler.read().await;
+                    handler.timeout_drop(&self);
+                }
                 return false;
             }
         }
@@ -180,32 +196,38 @@ where
         if !self.check_rules(&event, &config) {
             return false;
         }
-        let handler = self.handler.clone();
-        if !handler.match_(&mut event) {
-            return false;
+        {
+            let handler = self.handler.read().await;
+            if !handler.match_(&mut event) {
+                return false;
+            }
+            let matcher = self.clone().set_event(&event);
+            let handler = self.handler.clone();
+            tokio::spawn(async move {
+                let handler = handler.read().await;
+                handler.handle(event, matcher).await
+            });
         }
-        let matcher = self.clone().set_event(&event);
-        tokio::spawn(async move { handler.handle(event, matcher).await });
         return true;
     }
 
     /// 发送 nbrs 内部设置 Action
     pub async fn set(&self, set: Action) {
-        self.bot
-            .clone()
-            .unwrap()
-            .api_sender
-            .send(crate::ApiChannelItem::Action(set))
-            .await
-            .unwrap();
+        if let Some(bot) = &self.bot {
+            bot.action_sender.send(set).await.unwrap();
+        }
     }
 
-    /// 向指定 bot_id 添加 Matcher<MessageEvent>
+    /// 向 Matchers 添加 Matcher<MessageEvent>
     pub async fn set_message_matcher(&self, matcher: Matcher<MessageEvent>) {
-        let set = Action::AddMessageEventMatcher {
+        let action = action::MatchersAction::AddMessageEventMatcher {
             message_event_matcher: matcher,
         };
-        self.set(set).await;
+        if let Some(action_sender) = &self.action_sender {
+            action_sender.send(action).unwrap();
+        } else {
+            tracing::event!(tracing::Level::WARN, "Action Sender not init.")
+        }
     }
 }
 
@@ -230,7 +252,7 @@ where
     .add_rule(crate::builtin::rules::is_user(event.get_user_id()))
     .add_rule(crate::builtin::rules::is_bot(event.get_self_id()));
     if let MessageEvent::Group(g) = event {
-        m.add_rule(crate::builtin::rules::in_group(g.group_id));
+        m.add_rule(crate::builtin::rules::in_group(g.group_id.clone()));
     } else {
         m.add_rule(crate::builtin::rules::is_private_message_event());
     }
