@@ -1,11 +1,14 @@
 use super::{Handler, Matcher, PreMatcher, Rule};
 use std::sync::Arc;
+use tokio::sync::RwLock;
 
 impl<E> Matcher<E>
 where
     E: Clone,
 {
-    /// 设置 Matcher 的 api_sender 与 api_resp_watcher
+    /// 设置 Matcher 的 bot
+    ///
+    /// 当前 Matcher 如果已经预设 Bot 将会忽视传入的 Bot
     pub fn build(&self, bot: crate::bot::Bot) -> Matcher<E> {
         let mut m = self.clone();
         if let None = &m.bot {
@@ -14,6 +17,12 @@ where
         m
     }
 
+    /// 为 Matcher 添加向 Matchers 发送 Matchers Action 的 Sender
+    /// 会在向 Matchers 添加时调用
+    pub fn set_action_sender(&mut self, action_sender: super::matchers::ActionSender) {
+        self.action_sender = Some(action_sender);
+    }
+
     /// 设置 priority
     pub fn set_priority(&mut self, priority: i8) -> Matcher<E> {
         self.priority = priority;
@@ -39,12 +48,15 @@ where
     }
 
     /// 获取 handler
-    pub fn get_handler(&self) -> &Arc<dyn Handler<E> + Sync + Send> {
+    pub fn get_handler(&self) -> &Arc<RwLock<dyn Handler<E> + Sync + Send>> {
         &self.handler
     }
 
     /// 设置 handler
-    pub fn set_handler(&mut self, handler: Arc<dyn Handler<E> + Sync + Send>) -> Matcher<E> {
+    pub fn set_handler(
+        &mut self,
+        handler: Arc<RwLock<dyn Handler<E> + Sync + Send>>,
+    ) -> Matcher<E> {
         self.handler = handler;
         self.clone()
     }
